local ADDON_NAME, addon = ...
local module = addon:NewModule("Config")

local fontOutline = {
  NONE="NONE",
  OUTLINE="OUTLINE",
  THICKOUTLINE="THICKOUTLINE"
}

local framePos = {
  TOPLEFT="TOPLEFT",
  TOP="TOP",
  TOPRIGHT="TOPRIGHT",
  LEFT="LEFT",
  CENTER="CENTER",
  RIGHT="RIGHT",
  BOTTOMLEFT="BOTTOMLEFT",
  BOTTOM="BOTTOM",
  BOTTOMRIGHT="BOTTOMRIGHT"
}

local config_mode = false

function addon:UpdateEclipseBar()
	local cfg = self.db.profile.eclipsebar
	local bar = self.EclipseBar
	local background = bar.Background

	bar:ClearAllPoints()
	bar:SetPoint(cfg.from, cfg.parent, cfg.to, cfg.posx, cfg.posy)

	bar:SetWidth(cfg.width)
	bar:SetHeight(cfg.height)
	bar:SetStatusBarTexture(self.LSM:Fetch("statusbar", cfg.texture))

	--  self.EclipseBar.EclipseLeft:ClearAllPoints()
	--  self.EclipseBar.EclipseLeft:SetPoint("RIGHT", self.EclipseBar, "LEFT", (cfg.height/30*12), 0)
	--  self.EclipseBar.EclipseLeft:SetWidth(cfg.height/30*60)
	--  self.EclipseBar.EclipseLeft:SetHeight(cfg.height/30*100)
	--  self.EclipseBar.EclipseRight:ClearAllPoints()
	--  self.EclipseBar.EclipseRight:SetPoint("LEFT", self.EclipseBar, "RIGHT", -(cfg.height/30*12), 0)
	--  self.EclipseBar.EclipseRight:SetWidth(cfg.height/30*60)
	--  self.EclipseBar.EclipseRight:SetHeight(cfg.height/30*100)

	background:ClearAllPoints()
	background:SetPoint("TOPLEFT", -cfg.backdrop.offset, cfg.backdrop.offset)
	background:SetPoint("BOTTOMRIGHT", cfg.backdrop.offset, -cfg.backdrop.offset)

	local p = UnitPower('player',SPELL_POWER_ECLIPSE)
	if p >= 0 then
		bar:SetStatusBarColor(cfg.solarcolor.r, cfg.solarcolor.g, cfg.solarcolor.b)
		bar.EclipseLeft:SetVertexColor(cfg.solarcolor.r, cfg.solarcolor.g, cfg.solarcolor.b)
		bar.EclipseRight:SetVertexColor(cfg.solarcolor.r, cfg.solarcolor.g, cfg.solarcolor.b)
	else
		bar:SetStatusBarColor(cfg.lunarcolor.r, cfg.lunarcolor.g, cfg.lunarcolor.b)
		bar.EclipseLeft:SetVertexColor(cfg.lunarcolor.r, cfg.lunarcolor.g, cfg.lunarcolor.b)
		bar.EclipseRight:SetVertexColor(cfg.lunarcolor.r, cfg.lunarcolor.g, cfg.lunarcolor.b)
	end

	background:SetBackdrop({
		bgFile = self.LSM:Fetch("background", cfg.backdrop.bgFile),
		edgeFile = self.LSM:Fetch("border", cfg.backdrop.edgeFile),
		tile = cfg.backdrop.tile,
		tileSize = cfg.backdrop.tileSize,
		edgeSize = cfg.backdrop.edgeSize,
		insets = {
			left = cfg.backdrop.inset,
			right = cfg.backdrop.inset,
			top = cfg.backdrop.inset,
			bottom = cfg.backdrop.inset
		}
	})

	background:SetBackdropColor(cfg.backdrop.color.r, cfg.backdrop.color.g, cfg.backdrop.color.b, cfg.backdrop.color.a)
	background:SetBackdropBorderColor(cfg.backdrop.bordercolor.r, cfg.backdrop.bordercolor.g, cfg.backdrop.bordercolor.b, cfg.backdrop.bordercolor.a)

	if cfg.showtextures == true then
		bar.EclipseLeft:Show()
		bar.EclipseRight:Show()
	else
		bar.EclipseLeft:Hide()
		bar.EclipseRight:Hide()
	end
end


function addon:UpdateTimer()
	local cfg = self.db.profile.eclipsebar
	self.EclipseBar.Timer:ClearAllPoints()
	self.EclipseBar.Timer:SetPoint(cfg.timer.from, self.EclipseBar, cfg.timer.to, cfg.timer.posx, cfg.timer.posy)

	self.EclipseBar.Timer:SetFont(self.LSM:Fetch("font", cfg.timer.font), cfg.timer.fontsize, cfg.timer.outline)
	self.EclipseBar.Timer:SetTextColor(cfg.timer.fontcolor.r, cfg.timer.fontcolor.g, cfg.timer.fontcolor.b)

	if cfg.timer.show == false then
		self.EclipseBar.Timer:Hide()
	else
		self.EclipseBar.Timer:Show()
	end
end

function addon:UpdateValue()
	local cfg = self.db.profile.eclipsebar
	self.EclipseBar.Value:ClearAllPoints()
	self.EclipseBar.Value:SetPoint(cfg.value.from, self.EclipseBar, cfg.value.to, cfg.value.posx, cfg.value.posy)

	self.EclipseBar.Value:SetFont(self.LSM:Fetch("font", cfg.value.font), cfg.value.fontsize, cfg.value.outline)
	self.EclipseBar.Value:SetTextColor(cfg.value.fontcolor.r, cfg.value.fontcolor.g, cfg.value.fontcolor.b)

	if cfg.value.show == false then
		self.EclipseBar.Value:Hide()
	else
		self.EclipseBar.Value:Show()
	end
end

function addon:UpdateExtraBars(bar,config,barcolor)
	local parent = bar:GetParent()
	local background = bar.Background

	bar:ClearAllPoints()
	bar:SetPoint(config.from, parent, config.to, config.posx, config.posy)

	background:SetBackdrop({
		bgFile = self.LSM:Fetch("background", config.backdrop.bgFile),
		edgeFile = self.LSM:Fetch("border", config.backdrop.edgeFile),
		tile = config.backdrop.tile,
		tileSize = config.backdrop.tileSize,
		edgeSize = config.backdrop.edgeSize,
		insets = {
			left = config.backdrop.inset,
			right = config.backdrop.inset,
			top = config.backdrop.inset,
			bottom = config.backdrop.inset
		}
	})
	background:SetBackdropColor(config.backdrop.color.r, config.backdrop.color.g, config.backdrop.color.b, config.backdrop.color.a)
	background:SetBackdropBorderColor(config.backdrop.bordercolor.r, config.backdrop.bordercolor.g, config.backdrop.bordercolor.b, config.backdrop.bordercolor.a)

	bar:SetWidth(config.width)
	bar:SetHeight(config.height)
	bar:SetStatusBarTexture(self.LSM:Fetch("statusbar", config.texture))

	background:ClearAllPoints()
	background:SetPoint("TOPLEFT", -config.backdrop.offset, config.backdrop.offset)
	background:SetPoint("BOTTOMRIGHT", config.backdrop.offset, -config.backdrop.offset)

	if barcolor == "alignment" or barcolor == "incarnation" then
		bar:SetStatusBarColor(config.barcolor.r, config.barcolor.g, config.barcolor.b)
	elseif barcolor == "starfall" then
		if checkGlyphs() == true then
			bar:SetStatusBarColor(config.solarcolor.r, config.solarcolor.g, config.solarcolor.b)
		else
			bar:SetStatusBarColor(config.lunarcolor.r, config.lunarcolor.g, config.lunarcolor.b)
		end
	end

	bar.Name:SetFont(self.LSM:Fetch("font", config.text.font), config.text.fontsize, config.text.outline)
	bar.Timer:SetFont(self.LSM:Fetch("font", config.text.font), config.text.fontsize, config.text.outline)

	bar.Name:SetTextColor(config.text.fontcolor.r, config.text.fontcolor.g, config.text.fontcolor.b)
	bar.Timer:SetTextColor(config.text.fontcolor.r, config.text.fontcolor.g, config.text.fontcolor.b)
end

function addon:UpdateStarsurge()
	local parent = self.ChargeA:GetParent()
	local cfg = self.db.profile.starsurge

	parent:ClearAllPoints()
	parent:SetPoint(cfg.from, parent:GetParent(), cfg.to, cfg.posx, cfg.posy)
	parent:SetWidth(cfg.size*3)
	parent:SetHeight(cfg.size)

	self.ChargeA:ClearAllPoints()
	self.ChargeA:SetPoint("TOPLEFT", parent, "TOPLEFT", 0, 0)
	self.ChargeA:SetWidth(cfg.size)
	self.ChargeA:SetHeight(cfg.size)

	self.ChargeB:ClearAllPoints()
	self.ChargeB:SetPoint("TOPLEFT", parent, "TOPLEFT", cfg.size, 0)
	self.ChargeB:SetWidth(cfg.size)
	self.ChargeB:SetHeight(cfg.size)

	self.ChargeC:ClearAllPoints()
	self.ChargeC:SetPoint("TOPLEFT", parent, "TOPLEFT", cfg.size*2, 0)
	self.ChargeC:SetWidth(cfg.size)
	self.ChargeC:SetHeight(cfg.size)
end

function addon:ToggleFade(value)
	if value == true then
		if InCombatLockdown() == false then
			self.EclipseBar:SetAlpha(self.db.profile.oocalpha);
		end
		--options.args.oocfade.disabled = false;
		self.EclipseBar:RegisterEvent("PLAYER_REGEN_ENABLED");
		self.EclipseBar:RegisterEvent("PLAYER_REGEN_DISABLED");
		else
		--options.args.oocfade.disabled = true;
		self.EclipseBar:SetAlpha(1)
		self.EclipseBar:UnregisterEvent("PLAYER_REGEN_ENABLED");
		self.EclipseBar:UnregisterEvent("PLAYER_REGEN_DISABLED");
		end
	end

function addon:ToggleConfigMode(value)
	if value == true then
		self.EclipseBar:SetAlpha(1)
		self.AlignmentBar:Show()
		self.IncarnationBar:SetValue(15)
		self.AlignmentBar.Timer:SetText("0.0")
		self.IncarnationBar:Show()
		self.IncarnationBar:SetValue(30)
		self.IncarnationBar.Timer:SetText("0.0")
		self.StarfallBar:Show()
		self.StarfallBar.Timer:SetText("0.0")
		self.Starsurge:Show()
		self.SolarEmpowerment:Show()
		self.SolarEmpowerment.Stacks:SetText("0")
		self.LunarEmpowerment:Show()
		self.LunarEmpowerment.Stacks:SetText("0")
		self.ForceOfNature:Show()
		self.ForceOfNature.Stacks:SetText("0")
		self.Moonfire:Show()
		self.Sunfire:Show()
		self.StellarFlare:Show()
	else
		self.AlignmentBar:Hide()
		self.IncarnationBar:Hide()
		self.StarfallBar:Hide()
		self.SolarEmpowerment:Hide()
		self.LunarEmpowerment:Hide()
		self.ForceOfNature:Hide()
		self.Moonfire:Hide()
		self.Sunfire:Hide()
		self.StellarFlare:Hide()
		
		if self.db.profile.oocfade == true then
			self.EclipseBar:SetAlpha(self.db.profile.oocalpha)
		end
		if self.db.profile.starsurge.enable == false then
			self.Starsurge:Hide()
		end
	end
end

function addon:ToggleStarsurge(value)
	if value == false and self.Starsurge:IsShown() == true then
		self.Starsurge:Hide()
	elseif value == true and self.Starsurge:IsShown() == false then
		self.Starsurge:Show()
	end
end

function addon:ToggleIcon(icon,value)
	if value == false and self.icon:IsShown() == true then
		icon:Hide()
	elseif value == true and self.icon:IsShown() == false then
		icon:SHow()
	end
end

function addon:UpdateIcon(icon,name)
	local cfg = addon.db.profile.icons[name]
	if cfg == nil then return end

	local parent = icon:GetParent()

	icon:ClearAllPoints()
	icon:SetPoint(cfg.from, parent, cfg.to, cfg.posx, cfg.posy)
	icon:SetWidth(cfg.size)
	icon:SetHeight(cfg.size)

	if name == "solarempowerment" or name == "lunarempowerment" or name == "forceofnature" then
		icon.Stacks:SetPoint("TOPRIGHT", icon, "TOPRIGHT", 4, 4)
		icon.Stacks:SetFont(self.LSM:Fetch("font", cfg.font), cfg.fontsize, cfg.outline)
		icon.Stacks:SetTextColor(cfg.fontcolor.r, cfg.fontcolor.g, cfg.fontcolor.b)
	end
end

local function GetOptions()
	local cfg = addon.db.profile
	local options = {
		type = "group",
		name = "DayNightCycle",
		get = function(info) return db[info[#info]] end,
		set = function(info, value) db[info[#info]] = value end,
		args = {
				description = {
				name = "A simple addon to show a customizable eclipse bar for Balance Druids. Addon based on the WeakAuras script by Cyous and Lappee.",
				type = "description",
				order = 1
			},
			oocfade = {
				name = "Fade out of combat",
				type = "toggle",
				order = 2,
					set = function(info, val) cfg.oocfade = val; addon:ToggleFade(val); end,
					get = function(info) return cfg.oocfade end,
			},
			oocalpha = {
				name = "Out of combat Alpha",
				type = "range",
				min = 0,
					max = 1,
					step = 0.01,
				order = 3,
				disabled = function(info) return not cfg.oocfade end,
					set = function(info, val) cfg.oocalpha = val; if cfg.oocfade == true and not InCombatLockdown() then addon.EclipseBar:SetAlpha(val); end end,
					get = function(info) return cfg.oocalpha end,
			},
			config_mode = {
				name = "Configuration Mode",
				type = "toggle",
				order = 4,
					set = function(info, val) config_mode = val; addon:ToggleConfigMode(val); end,
					get = function(info) return config_mode end,
			},
			eclipsebar = {
				name = "Eclipse Bar",
				type = "group",
				order = 5,
				args = {
						eclipsebar_header1 = {
							name = "Bar Position",
							type = "header",
						order = 1
					},
						eclipsebar_parent = {
						name = "Parent",
						type = "input",
							set = function(info, val) cfg.eclipsebar.parent = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.parent end,
						order = 2
					},
					eclipsebar_spacer1 = {
						name = "",
						type = "description",
						order = 3
					},
					eclipsebar_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.from = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.from end,
						order = 4
					},
					eclipsebar_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.to = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.to end,
						order = 5
					},
					eclipsebar_spacer2 = {
						name = "",
						type = "description",
						order = 6
					},
					eclipsebar_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.posx = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.posx end,
						order = 7
					},
					eclipsebar_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.posy = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.posy end,
						order = 8
						},
					eclipsebar_spacer3 = {
						name = "\n",
						type = "description",
						order = 9
					},
						eclipsebar_header2 = {
							name = "Bar Size",
							type = "header",
						order = 10
					},
					eclipsebar_width = {
						name = "Width",
						type = "range",
						min = 20,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.width = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.width end,
						order = 11
					},
					eclipsebar_height = {
						name = "Height",
						type = "range",
							min = 1,
						max = 80,
						step = 1,
							set = function(info, val) cfg.eclipsebar.height = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.height end,
						order = 12
					},
					eclipsebar_spacer4 = {
						name = "\n",
						type = "description",
						order = 13
					},
						eclipsebar_header3 = {
							name = "Bar Options",
							type = "header",
						order = 14
					},
					eclipsebar_solarcolor = {
						name = "Solar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.eclipsebar.solarcolor.r = r; cfg.eclipsebar.solarcolor.g = g; cfg.eclipsebar.solarcolor.b = b; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.solarcolor.r, cfg.eclipsebar.solarcolor.g, cfg.eclipsebar.solarcolor.b end,
						order = 15
					},
					eclipsebar_lunarcolor = {
						name = "Lunar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.eclipsebar.lunarcolor.r = r; cfg.eclipsebar.lunarcolor.g = g; cfg.eclipsebar.lunarcolor.b = b; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.lunarcolor.r, cfg.eclipsebar.lunarcolor.g, cfg.eclipsebar.lunarcolor.b end,
						order = 16
					},
					eclipsebar_texture = {
						name = "Texture",
						type = "select",
					dialogControl = "LSM30_Statusbar",
					values = AceGUIWidgetLSMlists.statusbar,
						width = "double",
							set = function(info, val) cfg.eclipsebar.texture = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.texture end,
						order = 17
					},
					eclipsebar_spacer5 = {
						name = "\n",
						type = "description",
						order = 18
					},
						eclipsebar_header5 = {
							name = "Backdrop Options",
							type = "header",
						order = 19
					},
					eclipsebar_backdrop_border = {
						name = "Border Style",
						type = "select",
					dialogControl = "LSM30_Border",
					values = AceGUIWidgetLSMlists.border,
							set = function(info, val) cfg.eclipsebar.backdrop.edgeFile = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.edgeFile end,
						order = 20
					},
					eclipsebar_backdrop_background = {
						name = "Backdrop Style",
						type = "select",
					dialogControl = "LSM30_Background",
					values = AceGUIWidgetLSMlists.background,
							set = function(info, val) cfg.eclipsebar.backdrop.bgFile	= val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.bgFile	end,
						order = 21
					},
					eclipsebar_spacer6 = {
						name = "",
						type = "description",
						order = 22
					},
					eclipsebar_backdrop_bordercorder = {
						name = "Border Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.eclipsebar.backdrop.bordercolor.r = r; cfg.eclipsebar.backdrop.bordercolor.g = g; cfg.eclipsebar.backdrop.bordercolor.b = b; cfg.eclipsebar.backdrop.bordercolor.a = a; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.bordercolor.r, cfg.eclipsebar.backdrop.bordercolor.g, cfg.eclipsebar.backdrop.bordercolor.b, cfg.eclipsebar.backdrop.bordercolor.a end,
						order = 23
					},
					eclipsebar_backdrop_color = {
						name = "Backdrop Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.eclipsebar.backdrop.color.r = r; cfg.eclipsebar.backdrop.color.g = g; cfg.eclipsebar.backdrop.color.b = b; cfg.eclipsebar.backdrop.color.a = a; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.color.r, cfg.eclipsebar.backdrop.color.g, cfg.eclipsebar.backdrop.color.b, cfg.eclipsebar.backdrop.color.a end,
						order = 24
					},
					eclipsebar_spacer7 = {
						name = "",
						type = "description",
						order = 25
					},
					eclipsebar_backdrop_offset = {
						name = "Border Offset",
						type = "range",
							min = 0,
						max = 32,
						step = 1,
							set = function(info, val) cfg.eclipsebar.backdrop.offset = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.offset end,
						order = 26
					},
					eclipsebar_backdrop_edgesize = {
						name = "Border Size",
						type = "range",
							min = 1,
						max = 64,
						step = 1,
							set = function(info, val) cfg.eclipsebar.backdrop.edgeSize = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.edgeSize end,
						order = 27
					},
					eclipsebar_spacer8 = {
						name = "",
						type = "description",
						order = 28
					},
					eclipsebar_backdrop_inset = {
						name = "Border Inset",
						type = "range",
							min = 1,
						max = 32,
						step = 1,
							set = function(info, val) cfg.eclipsebar.backdrop.inset = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.backdrop.inset end,
						order = 29
					},
					eclipsebar_spacer9 = {
						name = "\n",
						type = "description",
						order = 30
					},
						eclipsebar_header6 = {
							name = "Additional Textures",
							type = "header",
						order = 30
					},
						eclipsebar_showtextures = {
							name = "Enable Sun/Moon Textures",
							desc = "Enables / disables the additional Sun/Moon Textures",
							type = "toggle",
							set = function(info, val) cfg.eclipsebar.showtextures = val; addon:UpdateEclipseBar(); end,
							get = function(info) return cfg.eclipsebar.showtextures end,
						order = 31
						},
				},
			},
			eclipsebar_timer = {
				name = "Eclipse Timer",
				type = "group",
				order = 6,
				args = {
					-- Timer Text
						eclipsebar_timer_header1 = {
							name = "General",
							type = "header",
						order = 1
					},
						eclipsebar_timer_enable = {
							name = "Enable",
							desc = "Enables / disables the timer",
							type = "toggle",
							set = function(info, val) cfg.eclipsebar.timer.show = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.show end,
						order = 2
						},
					eclipsebar_timer_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						eclipsebar_timer_header2 = {
							name = "Text Position",
							type = "header",
						order = 4
					},
					eclipsebar_timer_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.timer.from = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.from end,
						order = 5
					},
					eclipsebar_timer_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.timer.to = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.to end,
						order = 6
					},
					eclipsebar_timer_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					eclipsebar_timer_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.timer.posx = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.posx end,
						order = 8
					},
					eclipsebar_timer_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.timer.posy = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.posy end,
						order = 9
					},
					eclipsebar_timer_spacer3 = {
						name = "\n",
						type = "description",
						order = 10
					},
						eclipsebar_timer_header3 = {
							name = "Font Options",
							type = "header",
						order = 11
					},
					eclipsebar_timer_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.eclipsebar.timer.font = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.font end,
						order = 12
					},
					eclipsebar_timer_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.eclipsebar.timer.fontsize = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.fontsize end,
						order = 13
					},
					eclipsebar_timer_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.eclipsebar.timer.fontcolor.r = r; cfg.eclipsebar.timer.fontcolor.g = g; cfg.eclipsebar.timer.fontcolor.b = b; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.fontcolor.r, cfg.eclipsebar.timer.fontcolor.g, cfg.eclipsebar.timer.fontcolor.b end,
						order = 14
					},
					eclipsebar_timer_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.timer.outline = val; addon:UpdateTimer(); end,
							get = function(info) return cfg.eclipsebar.timer.outline end,
						order = 15
					}
				}
			},
			eclipsebar_value = {
				name = "Eclipse Value",
				type = "group",
				order = 7,
				args = {
					-- Value Text
						eclipsebar_value_header1 = {
							name = "General",
							type = "header",
						order = 1
					},
						eclipsebar_value_enable = {
							name = "Enable",
							desc = "Enables / disables the value",
							type = "toggle",
							set = function(info, val) cfg.eclipsebar.value.show = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.show end,
						order = 2
						},
					eclipsebar_value_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						eclipsebar_value_header2 = {
							name = "Text Position",
							type = "header",
						order = 4
					},
					eclipsebar_value_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.value.from = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.from end,
						order = 5
					},
					eclipsebar_value_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.value.to = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.to end,
						order = 6
					},
					eclipsebar_value_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					eclipsebar_value_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.value.posx = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.posx end,
						order = 8
					},
					eclipsebar_value_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.eclipsebar.value.posy = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.posy end,
						order = 9
					},
					eclipsebar_value_spacer3 = {
						name = "\n",
						type = "description",
						order = 10
					},
						eclipsebar_value_header3 = {
							name = "Font Options",
							type = "header",
						order = 11
					},
					eclipsebar_value_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.eclipsebar.value.font = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.font end,
						order = 12
					},
					eclipsebar_value_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.eclipsebar.value.fontsize = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.fontsize end,
						order = 13
					},
					eclipsebar_timer_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.eclipsebar.value.fontcolor.r = r; cfg.eclipsebar.value.fontcolor.g = g; cfg.eclipsebar.value.fontcolor.b = b; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.fontcolor.r, cfg.eclipsebar.value.fontcolor.g, cfg.eclipsebar.value.fontcolor.b end,
						order = 14
					},
					eclipsebar_value_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.eclipsebar.value.outline = val; addon:UpdateValue(); end,
							get = function(info) return cfg.eclipsebar.value.outline end,
						order = 15
					}
					},
			},
				
				-- Celestial Alignment Bar
			alignmentbar = {
				name = "Celestial Alignment Bar",
				type = "group",
				order = 8,
				args = {
					enable = {
						name = "Enable Bar",
						type = "toggle",
						order = 0,
							set = function(info, val) cfg.alignmentbar.enable = val; if addon.AlignmentBar.Background:IsShown() == true then addon.AlignmentBar.Background:Hide(); end end,
							get = function(info) return cfg.alignmentbar.enable end,
					},
						alignmentbar_header1 = {
							name = "Bar Position",
							type = "header",
						order = 1
					},
					alignmentbar_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.alignmentbar.from = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.from end,
						order = 2
					},
					alignmentbar_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.alignmentbar.to = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.to end,
						order = 3
					},
					alignmentbar_spacer1 = {
						name = "",
						type = "description",
						order = 4
					},
					alignmentbar_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.alignmentbar.posx = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.posx end,
						order = 5
					},
					alignmentbar_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.alignmentbar.posy = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.posy end,
						order = 6
					},
					alignmentbar_spacer2 = {
						name = "\n",
						type = "description",
						order = 7
					},
						alignmentbar_header2 = {
							name = "Bar Size",
							type = "header",
						order = 8
					},
					alignmentbar_width = {
						name = "Width",
						type = "range",
						min = 20,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.alignmentbar.width = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.width end,
						order = 9
					},
					alignmentbar_height = {
						name = "Height",
						type = "range",
							min = 1,
						max = 80,
						step = 1,
							set = function(info, val) cfg.alignmentbar.height = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.height end,
						order = 10
					},
					alignmentbar_spacer3 = {
						name = "\n",
						type = "description",
						order = 11
					},
						alignmentbar_header3 = {
							name = "Bar Options",
							type = "header",
						order = 12
					},
					alignmentbar_barcolor = {
						name = "Bar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.alignmentbar.barcolor.r = r; cfg.alignmentbar.barcolor.g = g; cfg.alignmentbar.barcolor.b = b; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar, "alignment"); end,
							get = function(info) return cfg.alignmentbar.barcolor.r, cfg.alignmentbar.barcolor.g, cfg.alignmentbar.barcolor.b end,
						order = 13
					},
					alignmentbar_texture = {
						name = "Texture",
						type = "select",
					dialogControl = "LSM30_Statusbar",
					values = AceGUIWidgetLSMlists.statusbar,
						width = "double",
							set = function(info, val) cfg.alignmentbar.texture = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.texture end,
						order = 14
					},
					alignmentbar_spacer4 = {
						name = "\n",
						type = "description",
						order = 15
					},
						alignmentbar_header4 = {
							name = "Font Options",
							type = "header",
						order = 16
					},
					alignmentbar_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.alignmentbar.text.font = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.text.font end,
						order = 17
					},
					alignmentbar_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.alignmentbar.text.fontsize = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.text.fontsize end,
						order = 18
					},
					alignmentbar_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.alignmentbar.text.fontcolor.r = r; cfg.alignmentbar.text.fontcolor.g = g; cfg.alignmentbar.text.fontcolor.b = b; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.text.fontcolor.r, cfg.alignmentbar.text.fontcolor.g, cfg.alignmentbar.text.fontcolor.b end,
						order = 19
					},
					alignmentbar_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.alignmentbar.text.outline = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.text.outline end,
						order = 20
					},
					alignmentbar_spacer5 = {
						name = "\n",
						type = "description",
						order = 21
					},
						alignmentbar_header5 = {
							name = "Backdrop Options",
							type = "header",
						order = 22
					},
					alignmentbar_backdrop_border = {
						name = "Border Style",
						type = "select",
					dialogControl = "LSM30_Border",
					values = AceGUIWidgetLSMlists.border,
							set = function(info, val) cfg.alignmentbar.backdrop.edgeFile = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.edgeFile end,
						order = 23
					},
					alignmentbar_backdrop_background = {
						name = "Backdrop Style",
						type = "select",
					dialogControl = "LSM30_Background",
					values = AceGUIWidgetLSMlists.background,
							set = function(info, val) cfg.alignmentbar.backdrop.bgFile	= val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.bgFile	end,
						order = 24
					},
					alignmentbar_spacer6 = {
						name = "",
						type = "description",
						order = 25
					},
					alignmentbar_backdrop_bordercorder = {
						name = "Border Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.alignmentbar.backdrop.bordercolor.r = r; cfg.alignmentbar.backdrop.bordercolor.g = g; cfg.alignmentbar.backdrop.bordercolor.b = b; cfg.alignmentbar.backdrop.bordercolor.a = a; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.bordercolor.r, cfg.alignmentbar.backdrop.bordercolor.g, cfg.alignmentbar.backdrop.bordercolor.b, cfg.alignmentbar.backdrop.bordercolor.a end,
						order = 26
					},
					alignmentbar_backdrop_color = {
						name = "Backdrop Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.alignmentbar.backdrop.color.r = r; cfg.alignmentbar.backdrop.color.g = g; cfg.alignmentbar.backdrop.color.b = b; cfg.alignmentbar.backdrop.color.a = a; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.color.r, cfg.alignmentbar.backdrop.color.g, cfg.alignmentbar.backdrop.color.b, cfg.alignmentbar.backdrop.color.a end,
						order = 27
					},
					alignmentbar_spacer7 = {
						name = "",
						type = "description",
						order = 28
					},
					alignmentbar_backdrop_offset = {
						name = "Border Offset",
						type = "range",
							min = 0,
						max = 32,
						step = 1,
							set = function(info, val) cfg.alignmentbar.backdrop.offset = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.offset end,
						order = 29
					},
					alignmentbar_backdrop_edgesize = {
						name = "Border Size",
						type = "range",
							min = 1,
						max = 64,
						step = 1,
							set = function(info, val) cfg.alignmentbar.backdrop.edgeSize = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.edgeSize end,
						order = 30
					},
					alignmentbar_spacer8 = {
						name = "",
						type = "description",
						order = 31
					},
					alignmentbar_backdrop_inset = {
						name = "Border Inset",
						type = "range",
							min = 1,
						max = 32,
						step = 1,
							set = function(info, val) cfg.alignmentbar.backdrop.inset = val; addon:UpdateExtraBars(addon.AlignmentBar, cfg.alignmentbar); end,
							get = function(info) return cfg.alignmentbar.backdrop.inset end,
						order = 32
					}
					}
			},
				
				-- Incarnation Bar
			incarnationbar = {
				name = "Incarnation Bar",
				type = "group",
				order = 9,
				args = {
					enable = {
						name = "Enable Bar",
						type = "toggle",
						order = 0,
							set = function(info, val) cfg.incarnationbar.enable = val; if addon.IncarnationBar.Background:IsShown() == true then addon.IncarnationBar.Background:Hide(); end end,
							get = function(info) return cfg.incarnationbar.enable end,
					},
						incarnationbar_header1 = {
							name = "Bar Position",
							type = "header",
						order = 1
					},
					incarnationbar_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.incarnationbar.from = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.from end,
						order = 2
					},
					incarnationbar_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.incarnationbar.to = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.to end,
						order = 3
					},
					incarnationbar_spacer1 = {
						name = "",
						type = "description",
						order = 4
					},
					incarnationbar_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.incarnationbar.posx = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.posx end,
						order = 5
					},
					incarnationbar_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.incarnationbar.posy = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.posy end,
						order = 6
					},
					incarnationbar_spacer2 = {
						name = "\n",
						type = "description",
						order = 7
					},
						incarnationbar_header2 = {
							name = "Bar Size",
							type = "header",
						order = 8
					},
					incarnationbar_width = {
						name = "Width",
						type = "range",
						min = 20,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.incarnationbar.width = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.width end,
						order = 9
					},
					incarnationbar_height = {
						name = "Height",
						type = "range",
							min = 1,
						max = 80,
						step = 1,
							set = function(info, val) cfg.incarnationbar.height = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.height end,
						order = 10
					},
					incarnationbar_spacer3 = {
						name = "\n",
						type = "description",
						order = 11
					},
						incarnationbar_header3 = {
							name = "Bar Options",
							type = "header",
						order = 12
					},
					incarnationbar_barcolor = {
						name = "Bar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.incarnationbar.barcolor.r = r; cfg.incarnationbar.barcolor.g = g; cfg.incarnationbar.barcolor.b = b; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar, "incarnation"); end,
							get = function(info) return cfg.incarnationbar.barcolor.r, cfg.incarnationbar.barcolor.g, cfg.incarnationbar.barcolor.b end,
						order = 13
					},
					incarnationbar_texture = {
						name = "Texture",
						type = "select",
					dialogControl = "LSM30_Statusbar",
					values = AceGUIWidgetLSMlists.statusbar,
						width = "double",
							set = function(info, val) cfg.incarnationbar.texture = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.texture end,
						order = 14
					},
					incarnationbar_spacer4 = {
						name = "\n",
						type = "description",
						order = 15
					},
						incarnationbar_header4 = {
							name = "Font Options",
							type = "header",
						order = 16
					},
					incarnationbar_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.incarnationbar.text.font = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.text.font end,
						order = 17
					},
					incarnationbar_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.incarnationbar.text.fontsize = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.text.fontsize end,
						order = 18
					},
					incarnationbar_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.incarnationbar.text.fontcolor.r = r; cfg.incarnationbar.text.fontcolor.g = g; cfg.incarnationbar.text.fontcolor.b = b; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.text.fontcolor.r, cfg.incarnationbar.text.fontcolor.g, cfg.incarnationbar.text.fontcolor.b end,
						order = 19
					},
					incarnationbar_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.incarnationbar.text.outline = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.text.outline end,
						order = 19
					},
					incarnationbar_spacer5 = {
						name = "\n",
						type = "description",
						order = 20
					},
						incarnationbar_header5 = {
							name = "Backdrop Options",
							type = "header",
						order = 21
					},
					incarnationbar_backdrop_border = {
						name = "Border Style",
						type = "select",
					dialogControl = "LSM30_Border",
					values = AceGUIWidgetLSMlists.border,
							set = function(info, val) cfg.incarnationbar.backdrop.edgeFile = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.edgeFile end,
						order = 22
					},
					incarnationbar_backdrop_background = {
						name = "Backdrop Style",
						type = "select",
					dialogControl = "LSM30_Background",
					values = AceGUIWidgetLSMlists.background,
							set = function(info, val) cfg.incarnationbar.backdrop.bgFile	= val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.bgFile	end,
						order = 23
					},
					incarnationbar_spacer6 = {
						name = "",
						type = "description",
						order = 24
					},
					incarnationbar_backdrop_bordercorder = {
						name = "Border Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.incarnationbar.backdrop.bordercolor.r = r; cfg.incarnationbar.backdrop.bordercolor.g = g; cfg.incarnationbar.backdrop.bordercolor.b = b; cfg.incarnationbar.backdrop.bordercolor.a = a; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.bordercolor.r, cfg.incarnationbar.backdrop.bordercolor.g, cfg.incarnationbar.backdrop.bordercolor.b, cfg.incarnationbar.backdrop.bordercolor.a end,
						order = 25
					},
					incarnationbar_backdrop_color = {
						name = "Backdrop Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.incarnationbar.backdrop.color.r = r; cfg.incarnationbar.backdrop.color.g = g; cfg.incarnationbar.backdrop.color.b = b; cfg.incarnationbar.backdrop.color.a = a; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.color.r, cfg.incarnationbar.backdrop.color.g, cfg.incarnationbar.backdrop.color.b, cfg.incarnationbar.backdrop.color.a end,
						order = 26
					},
					incarnationbar_spacer7 = {
						name = "",
						type = "description",
						order = 27
					},
					incarnationbar_backdrop_offset = {
						name = "Border Offset",
						type = "range",
							min = 0,
						max = 32,
						step = 1,
							set = function(info, val) cfg.incarnationbar.backdrop.offset = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.offset end,
						order = 28
					},
					incarnationbar_backdrop_edgesize = {
						name = "Border Size",
						type = "range",
							min = 1,
						max = 64,
						step = 1,
							set = function(info, val) cfg.incarnationbar.backdrop.edgeSize = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.edgeSize end,
						order = 29
					},
					incarnationbar_spacer8 = {
						name = "",
						type = "description",
						order = 30
					},
					incarnationbar_backdrop_inset = {
						name = "Border Inset",
						type = "range",
							min = 1,
						max = 32,
						step = 1,
							set = function(info, val) cfg.incarnationbar.backdrop.inset = val; addon:UpdateExtraBars(addon.IncarnationBar, cfg.incarnationbar); end,
							get = function(info) return cfg.incarnationbar.backdrop.inset end,
						order = 31
					}
					}
			},
				
				-- Starfall Bar
			starfallbar = {
				name = "Starfall Bar",
				type = "group",
				order = 10,
				args = {
					enable = {
						name = "Enable Bar",
						type = "toggle",
						order = 0,
							set = function(info, val) cfg.starfallbar.enable = val; if addon.StarfallBar.Background:IsShown() == true then addon.StarfallBar.Background:Hide(); end end,
							get = function(info) return cfg.starfallbar.enable end,
					},
						starfallbar_header1 = {
							name = "Bar Position",
							type = "header",
						order = 1
					},
					starfallbar_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.starfallbar.from = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.from end,
						order = 2
					},
					starfallbar_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.starfallbar.to = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.to end,
						order = 3
					},
					starfallbar_spacer1 = {
						name = "",
						type = "description",
						order = 4
					},
					starfallbar_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.starfallbar.posx = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.posx end,
						order = 5
					},
					starfallbar_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.starfallbar.posy = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.posy end,
						order = 6
					},
					starfallbar_spacer2 = {
						name = "\n",
						type = "description",
						order = 7
					},
						starfallbar_header2 = {
							name = "Bar Size",
							type = "header",
						order = 8
					},
					starfallbar_width = {
						name = "Width",
						type = "range",
						min = 20,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.starfallbar.width = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.width end,
						order = 9
					},
					starfallbar_height = {
						name = "Height",
						type = "range",
							min = 1,
						max = 80,
						step = 1,
							set = function(info, val) cfg.starfallbar.height = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.height end,
						order = 10
					},
					starfallbar_spacer3 = {
						name = "\n",
						type = "description",
						order = 11
					},
						starfallbar_header3 = {
							name = "Bar Options",
							type = "header",
						order = 12
					},
					starfallbar_solarcolor = {
						name = "Sunfall Bar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.starfallbar.solarcolor.r = r; cfg.starfallbar.solarcolor.g = g; cfg.starfallbar.solarcolor.b = b; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar, "starfall"); end,
							get = function(info) return cfg.starfallbar.solarcolor.r, cfg.starfallbar.solarcolor.g, cfg.starfallbar.solarcolor.b end,
						order = 13
					},
					starfallbar_lunarcolor = {
						name = "Starfall Bar Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.starfallbar.lunarcolor.r = r; cfg.starfallbar.lunarcolor.g = g; cfg.starfallbar.lunarcolor.b = b; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar, "starfall"); end,
							get = function(info) return cfg.starfallbar.lunarcolor.r, cfg.starfallbar.lunarcolor.g, cfg.starfallbar.lunarcolor.b end,
						order = 14
					},
					starfallbar_texture = {
						name = "Texture",
						type = "select",
					dialogControl = "LSM30_Statusbar",
					values = AceGUIWidgetLSMlists.statusbar,
						width = "double",
							set = function(info, val) cfg.starfallbar.texture = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.texture end,
						order = 15
					},
					starfallbar_spacer4 = {
						name = "\n",
						type = "description",
						order = 16
					},
						starfallbar_header4 = {
							name = "Font Options",
							type = "header",
						order = 17
					},
					starfallbar_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.starfallbar.text.font = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.text.font end,
						order = 18
					},
					starfallbar_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.starfallbar.text.fontsize = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.text.fontsize end,
						order = 19
					},
					starfallbar_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.starfallbar.text.fontcolor.r = r; cfg.starfallbar.text.fontcolor.g = g; cfg.starfallbar.text.fontcolor.b = b; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.text.fontcolor.r, cfg.starfallbar.text.fontcolor.g, cfg.starfallbar.text.fontcolor.b end,
						order = 20
					},
					starfallbar_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.starfallbar.text.outline = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.text.outline end,
						order = 21
					},
					starfallbar_spacer5 = {
						name = "\n",
						type = "description",
						order = 22
					},
						starfallbar_header5 = {
							name = "Backdrop Options",
							type = "header",
						order = 23
					},
					starfallbar_backdrop_border = {
						name = "Border Style",
						type = "select",
					dialogControl = "LSM30_Border",
					values = AceGUIWidgetLSMlists.border,
							set = function(info, val) cfg.starfallbar.backdrop.edgeFile = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.edgeFile end,
						order = 24
					},
					starfallbar_backdrop_background = {
						name = "Backdrop Style",
						type = "select",
					dialogControl = "LSM30_Background",
					values = AceGUIWidgetLSMlists.background,
							set = function(info, val) cfg.starfallbar.backdrop.bgFile	= val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.bgFile	end,
						order = 25
					},
					starfallbar_spacer6 = {
						name = "",
						type = "description",
						order = 26
					},
					starfallbar_backdrop_bordercorder = {
						name = "Border Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.starfallbar.backdrop.bordercolor.r = r; cfg.starfallbar.backdrop.bordercolor.g = g; cfg.starfallbar.backdrop.bordercolor.b = b; cfg.starfallbar.backdrop.bordercolor.a = a; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.bordercolor.r, cfg.starfallbar.backdrop.bordercolor.g, cfg.starfallbar.backdrop.bordercolor.b, cfg.starfallbar.backdrop.bordercolor.a end,
						order = 27
					},
					starfallbar_backdrop_color = {
						name = "Backdrop Color",
						type = "color",
					hasAlpha = true,
							set = function(info, r, g, b, a) cfg.starfallbar.backdrop.color.r = r; cfg.starfallbar.backdrop.color.g = g; cfg.starfallbar.backdrop.color.b = b; cfg.starfallbar.backdrop.color.a = a; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.color.r, cfg.starfallbar.backdrop.color.g, cfg.starfallbar.backdrop.color.b, cfg.starfallbar.backdrop.color.a end,
						order = 28
					},
					starfallbar_spacer7 = {
						name = "",
						type = "description",
						order = 29
					},
					starfallbar_backdrop_offset = {
						name = "Border Offset",
						type = "range",
							min = 0,
						max = 32,
						step = 1,
							set = function(info, val) cfg.starfallbar.backdrop.offset = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.offset end,
						order = 30
					},
					starfallbar_backdrop_edgesize = {
						name = "Border Size",
						type = "range",
							min = 1,
						max = 64,
						step = 1,
							set = function(info, val) cfg.starfallbar.backdrop.edgeSize = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.edgeSize end,
						order = 31
					},
					starfallbar_spacer8 = {
						name = "",
						type = "description",
						order = 32
					},
					starfallbar_backdrop_inset = {
						name = "Border Inset",
						type = "range",
							min = 1,
						max = 32,
						step = 1,
							set = function(info, val) cfg.starfallbar.backdrop.inset = val; addon:UpdateExtraBars(addon.StarfallBar, cfg.starfallbar); end,
							get = function(info) return cfg.starfallbar.backdrop.inset end,
						order = 33
					}
					}
			},
				
				-- Starsurge Charges
			starsurge = {
				name = "Starsurge Charges",
				type = "group",
				order = 11,
				args = {
					enable = {
						name = "Enable Bar",
						type = "toggle",
						order = 0,
							set = function(info, val) cfg.starsurge.enable = val; addon:ToggleStarsurge(val); end,
							get = function(info) return cfg.starsurge.enable end,
					},
						starsurge_header1 = {
							name = "Bar Position",
							type = "header",
						order = 1
					},
					starsurge_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.starsurge.from = val; addon:UpdateStarsurge(); end,
							get = function(info) return cfg.starsurge.from end,
						order = 2
					},
					starsurge_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.starsurge.to = val; addon:UpdateStarsurge(); end,
							get = function(info) return cfg.starsurge.to end,
						order = 3
					},
					starsurge_spacer1 = {
						name = "",
						type = "description",
						order = 4
					},
					starsurge_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.starsurge.posx = val; addon:UpdateStarsurge(); end,
							get = function(info) return cfg.starsurge.posx end,
						order = 5
					},
					starsurge_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.starsurge.posy = val; addon:UpdateStarsurge(); end,
							get = function(info) return cfg.starsurge.posy end,
						order = 6
					},
					starsurge_spacer2 = {
						name = "\n",
						type = "description",
						order = 7
					},
						starsurge_header2 = {
							name = "Bar Size",
							type = "header",
						order = 8
					},
					starsurge_width = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.starsurge.size = val; addon:UpdateStarsurge(); end,
							get = function(info) return cfg.starsurge.size end,
						order = 9
					},
				}
			},
			
			-- Solar Empowerment
			icons_solarempowerment = {
				name = "Solar Empowerment Icon",
				type = "group",
				order = 12,
				args = {
						icons_solarempowerment_header1 = {
							name = "General",
							type = "header",
						order = 0
					},
					icons_solarempowerment_enable = {
						name = "Enable Icon",
						type = "toggle",
						order = 1,
							set = function(info, val) cfg.icons.solarempowerment.enable = val; addon:ToggleIcon(addon.SolarEmpowerment,val); end,
							get = function(info) return cfg.icons.solarempowerment.enable end,
					},
					icons_solarempowerment_size = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.icons.solarempowerment.size = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.size end,
						order = 2
					},
					icons_solarempowerment_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						icons_solarempowerment_header2 = {
							name = "Icon Position",
							type = "header",
						order = 4
					},
					icons_solarempowerment_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.solarempowerment.from = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.from end,
						order = 5
					},
					icons_solarempowerment_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.solarempowerment.to = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.to end,
						order = 6
					},
					icons_solarempowerment_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					icons_solarempowerment_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.solarempowerment.posx = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.posx end,
						order = 8
					},
					icons_solarempowerment_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.solarempowerment.posy = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.posy end,
						order = 9
					},
					icons_solarempowerment_spacer3 = {
						name = "\n",
						type = "description",
						order = 10
					},
						icons_solarempowerment_header3 = {
							name = "Font Settings",
							type = "header",
						order = 11
					},
					icons_solarempowerment_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.icons.solarempowerment.font = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.font end,
						order = 12
					},
					icons_solarempowerment_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.icons.solarempowerment.fontsize = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.fontsize end,
						order = 13
					},
					icons_solarempowerment_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.icons.solarempowerment.fontcolor.r = r; cfg.icons.solarempowerment.fontcolor.g = g; cfg.icons.solarempowerment.fontcolor.b = b; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.fontcolor.r, cfg.icons.solarempowerment.fontcolor.g, cfg.icons.solarempowerment.fontcolor.b end,
						order = 14
					},
					icons_solarempowerment_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.icons.solarempowerment.outline = val; addon:UpdateIcon(addon.SolarEmpowerment,"solarempowerment"); end,
							get = function(info) return cfg.icons.solarempowerment.outline end,
						order = 15
					},
				},
			},
			
			-- Lunar Empowerment
			icons_lunarempowerment = {
				name = "Lunar Empowerment Icon",
				type = "group",
				order = 13,
				args = {
						icons_lunarempowerment_header1 = {
							name = "General",
							type = "header",
						order = 0
					},
					icons_lunarempowerment_enable = {
						name = "Enable Icon",
						type = "toggle",
						order = 1,
							set = function(info, val) cfg.icons.lunarempowerment.enable = val; addon:ToggleIcon(addon.LunarEmpowerment,val); end,
							get = function(info) return cfg.icons.lunarempowerment.enable end,
					},
					icons_lunarempowerment_size = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.icons.lunarempowerment.size = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.size end,
						order = 2
					},
					icons_lunarempowerment_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						icons_lunarempowerment_header2 = {
							name = "Icon Position",
							type = "header",
						order = 4
					},
					icons_lunarempowerment_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.lunarempowerment.from = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.from end,
						order = 5
					},
					icons_lunarempowerment_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.lunarempowerment.to = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.to end,
						order = 6
					},
					icons_lunarempowerment_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					icons_lunarempowerment_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.lunarempowerment.posx = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.posx end,
						order = 8
					},
					icons_lunarempowerment_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.lunarempowerment.posy = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.posy end,
						order = 9
					},
					icons_lunarempowerment_spacer3 = {
						name = "\n",
						type = "description",
						order = 10
					},
						icons_lunarempowerment_header3 = {
							name = "Font Settings",
							type = "header",
						order = 11
					},
					icons_lunarempowerment_font = {
						name = "Font",
						type = "select",
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
							set = function(info, val) cfg.icons.lunarempowerment.font = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.font end,
						order = 12
					},
					icons_lunarempowerment_fontsize = {
						name = "Font Size",
						type = "range",
					min = 6,
					max = 52,
					step = 1,
							set = function(info, val) cfg.icons.lunarempowerment.fontsize = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.fontsize end,
						order = 13
					},
					icons_lunarempowerment_fontcolor = {
						name = "Font Color",
						type = "color",
					hasAlpha = false,
							set = function(info, r, g, b) cfg.icons.lunarempowerment.fontcolor.r = r; cfg.icons.lunarempowerment.fontcolor.g = g; cfg.icons.lunarempowerment.fontcolor.b = b; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.fontcolor.r, cfg.icons.lunarempowerment.fontcolor.g, cfg.icons.lunarempowerment.fontcolor.b end,
						order = 14
					},
					icons_lunarempowerment_outline = {
						name = "Outline",
						type = "select",
						values = fontOutline,
						style = "dropdown",
							set = function(info, val) cfg.icons.lunarempowerment.outline = val; addon:UpdateIcon(addon.LunarEmpowerment,"lunarempowerment"); end,
							get = function(info) return cfg.icons.lunarempowerment.outline end,
						order = 15
					},
				},
			},
			
			-- Moonfire
			icons_moonfire = {
				name = "Moonfire Icon",
				type = "group",
				order = 14,
				args = {
						icons_moonfire_header1 = {
							name = "General",
							type = "header",
						order = 0
					},
					icons_moonfire_enable = {
						name = "Enable Icon",
						type = "toggle",
						order = 1,
							set = function(info, val) cfg.icons.moonfire.enable = val; addon:ToggleIcon(addon.Moonfire,val); end,
							get = function(info) return cfg.icons.moonfire.enable end,
					},
					icons_moonfire_size = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.icons.moonfire.size = val; addon:UpdateIcon(addon.Moonfire,"moonfire"); end,
							get = function(info) return cfg.icons.moonfire.size end,
						order = 2
					},
					icons_moonfire_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						icons_moonfire_header2 = {
							name = "Icon Position",
							type = "header",
						order = 4
					},
					icons_moonfire_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.moonfire.from = val; addon:UpdateIcon(addon.Moonfire,"moonfire"); end,
							get = function(info) return cfg.icons.moonfire.from end,
						order = 5
					},
					icons_moonfire_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.moonfire.to = val; addon:UpdateIcon(addon.Moonfire,"moonfire"); end,
							get = function(info) return cfg.icons.moonfire.to end,
						order = 6
					},
					icons_moonfire_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					icons_moonfire_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.moonfire.posx = val; addon:UpdateIcon(addon.Moonfire,"moonfire"); end,
							get = function(info) return cfg.icons.moonfire.posx end,
						order = 8
					},
					icons_moonfire_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.moonfire.posy = val; addon:UpdateIcon(addon.Moonfire,"moonfire"); end,
							get = function(info) return cfg.icons.moonfire.posy end,
						order = 9
					},
				},
			},
			
			-- Sunfire
			icons_sunfire = {
				name = "Sunfire Icon",
				type = "group",
				order = 15,
				args = {
						icons_sunfire_header1 = {
							name = "General",
							type = "header",
						order = 0
					},
					icons_sunfire_enable = {
						name = "Enable Icon",
						type = "toggle",
						order = 1,
							set = function(info, val) cfg.icons.sunfire.enable = val; addon:ToggleIcon(addon.Sunfire,val); end,
							get = function(info) return cfg.icons.sunfire.enable end,
					},
					icons_sunfire_size = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.icons.sunfire.size = val; addon:UpdateIcon(addon.Sunfire,"sunfire"); end,
							get = function(info) return cfg.icons.sunfire.size end,
						order = 2
					},
					icons_sunfire_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						icons_sunfire_header2 = {
							name = "Icon Position",
							type = "header",
						order = 4
					},
					icons_sunfire_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.sunfire.from = val; addon:UpdateIcon(addon.Sunfire,"sunfire"); end,
							get = function(info) return cfg.icons.sunfire.from end,
						order = 5
					},
					icons_sunfire_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.sunfire.to = val; addon:UpdateIcon(addon.Sunfire,"sunfire"); end,
							get = function(info) return cfg.icons.sunfire.to end,
						order = 6
					},
					icons_sunfire_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					icons_sunfire_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.sunfire.posx = val; addon:UpdateIcon(addon.Sunfire,"sunfire"); end,
							get = function(info) return cfg.icons.sunfire.posx end,
						order = 8
					},
					icons_sunfire_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.sunfire.posy = val; addon:UpdateIcon(addon.Sunfire,"sunfire"); end,
							get = function(info) return cfg.icons.sunfire.posy end,
						order = 9
					},
				},
			},
			
			-- Stellar Flare
			icons_stellarflare = {
				name = "Stellar Flare Icon",
				type = "group",
				order = 16,
				args = {
						icons_stellarflare_header1 = {
							name = "General",
							type = "header",
						order = 0
					},
					icons_stellarflare_enable = {
						name = "Enable Icon",
						type = "toggle",
						order = 1,
							set = function(info, val) cfg.icons.stellarflare.enable = val; addon:ToggleIcon(addon.StellarFlare,val); end,
							get = function(info) return cfg.icons.stellarflare.enable end,
					},
					icons_stellarflare_size = {
						name = "Size",
						type = "range",
						min = 10,
						max = 100,
						step = 1,
							set = function(info, val) cfg.icons.stellarflare.size = val; addon:UpdateIcon(addon.StellarFlare,"stellarflare"); end,
							get = function(info) return cfg.icons.stellarflare.size end,
						order = 2
					},
					icons_stellarflare_spacer1 = {
						name = "\n",
						type = "description",
						order = 3
					},
						icons_stellarflare_header2 = {
							name = "Icon Position",
							type = "header",
						order = 4
					},
					icons_stellarflare_from = {
						name = "Anchor",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.stellarflare.from = val; addon:UpdateIcon(addon.StellarFlare,"stellarflare"); end,
							get = function(info) return cfg.icons.stellarflare.from end,
						order = 5
					},
					icons_stellarflare_to = {
						name = "to parent's",
						type = "select",
						values = framePos,
						style = "dropdown",
							set = function(info, val) cfg.icons.stellarflare.to = val; addon:UpdateIcon(addon.StellarFlare,"stellarflare"); end,
							get = function(info) return cfg.icons.stellarflare.to end,
						order = 6
					},
					icons_stellarflare_spacer2 = {
						name = "",
						type = "description",
						order = 7
					},
					icons_stellarflare_posx = {
						name = "X Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.stellarflare.posx = val; addon:UpdateIcon(addon.StellarFlare,"stellarflare"); end,
							get = function(info) return cfg.icons.stellarflare.posx end,
						order = 8
					},
					icons_stellarflare_posy = {
						name = "Y Offset",
						type = "range",
						min = -1000,
						max = 1000,
						step = 1,
							set = function(info, val) cfg.icons.stellarflare.posy = val; addon:UpdateIcon(addon.StellarFlare,"stellarflare"); end,
							get = function(info) return cfg.icons.stellarflare.posy end,
						order = 9
					},
				},
			}
		}
	}

	return options
end

local L = {}
L["Profiles"] = "Profiles"

function module:OnInitialize()
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("DayNightCycle", GetOptions)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("DayNightCycle", ADDON_NAME)

	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("DayNightCycle/Profiles", LibStub("AceDBOptions-3.0"):GetOptionsTable(addon.db))
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("DayNightCycle/Profiles", L["Profiles"], ADDON_NAME)
end

-------------------------------------------------------------------------------
-- Slash Command Handler
-------------------------------------------------------------------------------
function addon:UpdateAll()
	local cfg = self.db.profile
	
	self:UpdateEclipseBar()
	self:UpdateExtraBars(self.AlignmentBar, cfg.alignmentbar)
	self:UpdateExtraBars(self.IncarnationBar, cfg.incarnationbar)
	self:UpdateExtraBars(self.StarfallBar, cfg.starfallbar)
	self:UpdateTimer()
	self:UpdateValue()
	self:UpdateStarsurge()
	
	self:ToggleFade(cfg.oocfade)
	self:ToggleStarsurge(cfg.starsurge.enable)
end

function addon:OpenOptions(msg, editbox)
	local cfg = addon.db.profile
	if msg == "convert" then
		if not cfg.isConverted then
		cfg.isConverted = true
	
		cfg.eclipsebar.width = cfg.eclipsebar.width-10
		if (cfg.eclipsebar.height-10) < 1 then cfg.eclipsebar.height = 1 else cfg.eclipsebar.height = cfg.eclipsebar.height-10 end
		cfg.eclipsebar.backdrop.offset = cfg.eclipsebar.backdrop.offset-2
		
		cfg.alignmentbar.width = cfg.alignmentbar.width-10
		if (cfg.alignmentbar.height-10) < 1 then cfg.alignmentbar.height = 1 else cfg.alignmentbar.height = cfg.alignmentbar.height-10 end
		cfg.alignmentbar.posy = cfg.alignmentbar.posy-10
		
		cfg.incarnationbar.width = cfg.incarnationbar.width-10
		if (cfg.incarnationbar.height-10) < 1 then cfg.incarnationbar.height = 1 else cfg.incarnationbar.height = cfg.incarnationbar.height-10 end
		cfg.incarnationbar.posy = cfg.incarnationbar.posy-10
		
		cfg.starfallbar.width = cfg.starfallbar.width-10
		if (cfg.starfallbar.height-10) < 1 then cfg.starfallbar.height = 1 else cfg.starfallbar.height = cfg.starfallbar.height-10 end
		cfg.starfallbar.posy = cfg.starfallbar.posy+10
		
		cfg.starsurge.posy = cfg.starsurge.posy+10
		
		self:UpdateAll()
	end
	else
		InterfaceOptionsFrame_OpenToCategory(ADDON_NAME)
		InterfaceOptionsFrame_OpenToCategory(ADDON_NAME)
	end
end

SLASH_DNC1 = "/dnc"
SlashCmdList["DNC"] = addon.OpenOptions
